@@ -1,5 +1,5 @@
 """
-Copyright (C) 2013-2017 Stefan Pfenninger.
+Copyright (C) 2013-2017 Calliope contributors listed in AUTHORS.
 Licensed under the Apache 2.0 License (see LICENSE file).
 
 optional.py
@@ -37,10 +37,10 @@ def ramping_rate(model):
                 return po.Constraint.NoConstraint
             else:
                 carrier = model.get_option(y + '.carrier')
-                diff = ((m.es_prod[carrier, y, x, t]
-                         + m.es_con[carrier, y, x, t]) / time_res.at[t]
-                        - (m.es_prod[carrier, y, x, model.prev_t(t)]
-                           + m.es_con[carrier, y, x, model.prev_t(t)])
+                diff = ((m.c_prod[carrier, y, x, t]
+                         + m.c_con[carrier, y, x, t]) / time_res.at[t]
+                        - (m.c_prod[carrier, y, x, model.prev_t(t)]
+                           + m.c_con[carrier, y, x, model.prev_t(t)])
                         / time_res.at[model.prev_t(t)])
                 max_ramping_rate = ramping_rate_value * m.e_cap[y, x]
                 if direction == 'up':
@@ -110,9 +110,9 @@ def group_fraction(model):
         sign, fraction = sign_fraction(output_group, 'output')
         techs = techs_to_consider(supply_techs, 'output')
         rhs = (fraction
-               * sum(m.es_prod[c, y, x, t] for y in techs
+               * sum(m.c_prod[c, y, x, t] for y in techs
                      for x in m.x for t in m.t))
-        lhs = sum(m.es_prod[c, y, x, t]
+        lhs = sum(m.c_prod[c, y, x, t]
                   for y in model.get_group_members(output_group) for x in m.x
                   for t in m.t)
         return equalizer(lhs, rhs, sign)
@@ -151,3 +151,58 @@ def group_fraction(model):
     grp = m.demand_power_peak_group
     m.c_group_fraction_demand_power_peak = \
         po.Constraint(m.c, grp, rule=c_group_fraction_demand_power_peak_rule)
+
+def max_r_area_per_loc(model):
+    """
+    ``r_area`` of all technologies requiring physical space cannot exceed the
+    available area of a location. Available area defined for parent locations
+    (in which there are locations defined as being 'within' it) will set the
+    available area limit for the sum of all the family (parent + all desecendants).
+
+    To define, assign a value to ``available_area`` for a given location, e.g.::
+
+        locations:
+            r1:
+                techs: ['csp']
+                available_area: 100000
+
+    To avoid including descendants in area limitation, ``ignore_descendants``
+    can be specified for the location, in the same way as ``available_area``.
+
+    """
+    m = model.m
+    locations = model._locations
+
+
+    def _get_descendants(x):
+        """
+        Returns all locations in the family tree of location x, in one list.
+        """
+        descendants = []
+        children = list(locations[locations._within == x].index)
+        if not children:
+            return []
+        for child in children:
+            descendants += _get_descendants(child)
+        descendants += children
+        return descendants
+
+    def c_available_r_area_rule(m, x):
+        available_area = model.config_model.get_key(
+                            'locations.{}.available_area'.format(x), default=None)
+        if not available_area:
+            return po.Constraint.Skip
+        if model.config_model.get_key(
+            'locations.{}.ignore_descendants'.format(x), default=False):
+            descendants = []
+        else:
+            descendants = _get_descendants(x)
+        all_x = descendants + [x]
+        r_area_sum = sum(m.r_area[y, _x] for y in m.y_r_area for _x in all_x if
+                         model.get_option(y + '.constraints.r_area.max', x=_x)
+                         is not False)
+        # r_area_sum will be ``0`` if either ``m.y_r_area`` or ``all_x`` are empty
+        if not isinstance(r_area_sum, int):
+            return (available_area >= r_area_sum)
+
+    m.c_available_r_area = po.Constraint(m.x, rule=c_available_r_area_rule)
