@@ -1,5 +1,5 @@
 """
-Copyright (C) 2013-2017 Stefan Pfenninger.
+Copyright (C) 2013-2017 Calliope contributors listed in AUTHORS.
 Licensed under the Apache 2.0 License (see LICENSE file).
 
 parallel.py
@@ -33,7 +33,7 @@ class Parallelizer(object):
         super(Parallelizer, self).__init__()
         if not config_run:
             config_run = os.path.join(os.path.dirname(__file__),
-                                      'example_model', 'run.yaml')
+                                      'example_models', 'national_scale', 'run.yaml')
         self.config_file = config_run
         self.config = utils.AttrDict.from_yaml(config_run)
         self.target_dir = target_dir
